@@ -154,7 +154,7 @@ restructure_config <- function(dots){
   result <- lapply(names(dots),
          function(a){validate_config(a, dots[[a]])})
   names(result) <- names(dots)
-  return(result)
+  result
 }
 
 #' Catch errors in user-provided config
@@ -164,7 +164,7 @@ restructure_config <- function(dots){
 #' @noRd
 #' @keywords Internal
 validate_config <- function(name, value, error_call = caller_env()) {
-  switch(name, 
+  result <- switch(name, 
          "api_key"         = enforce_character(value),
          "atlas" = {
            value <- configure_atlas(value)
@@ -173,9 +173,7 @@ validate_config <- function(name, value, error_call = caller_env()) {
          },
          "caching"         = enforce_logical(value),
          "directory"       = check_directory(value),
-         "download_reason_id" = {
-           value <- enforce_download_reason(value) |> 
-             convert_reason()},
+         "download_reason_id" = enforce_download_reason(value),
          "email"           = enforce_character(value),
          "password"        = enforce_character(value),
          "run_checks"      = enforce_logical(value),
@@ -183,7 +181,7 @@ validate_config <- function(name, value, error_call = caller_env()) {
          "username"        = enforce_character(value),
          "verbose"         = enforce_logical(value),
          enforce_invalid_name(name))
-  return(value)
+  result
 }
 
 #' Ensure some arguments are logical
@@ -193,6 +191,8 @@ validate_config <- function(name, value, error_call = caller_env()) {
 enforce_logical <- function(value, error_call = caller_env()){
   if (!is.logical(value)) {
     abort("Supplied value must be TRUE or FALSE.", call = error_call)
+  }else{
+    value
   }
 }
 
@@ -206,7 +206,7 @@ enforce_exists <- function(value, error_call = caller_env()){
                  i = "Does the directory entered exist?")
     abort(bullets, call = error_call)
   }else{
-    return(value)
+    value
   }
 }
 
@@ -221,6 +221,8 @@ enforce_character <- function(value, error_call = caller_env()){
       i = "Value must be entered as a string."
     )
     abort(bullets, call = error_call)
+  }else{
+    value
   }
 }
 
@@ -229,15 +231,21 @@ enforce_character <- function(value, error_call = caller_env()){
 #' @noRd
 #' @keywords Internal
 enforce_download_reason <- function(value, error_call = caller_env()){
-  if (is.numeric(value) & !(value %in% show_all_reasons()$id)) {
-    bullets <- c(
-      "Invalid download reason ID.",
-      i = "Use `show_all(reasons)` to see all valid reasons.",
-      x = glue("{value} does not match an existing reason ID.")
-    )
-    abort(bullets, call = error_call)
-  } else {
-    if(is.character(value) & !(value %in% show_all_reasons()$name)) {
+  # first ensure API is available. Currently missing for Brazil, for example.
+  
+  reasons_api_available <- url_lookup("metadata/reasons") |> 
+    try(silent = TRUE)
+  if(inherits(reasons_api_available, "try-error")){
+    return(1)
+  }else{
+    if (is.numeric(value) & !(value %in% show_all_reasons()$id)) {
+      bullets <- c(
+        "Invalid download reason ID.",
+        i = "Use `show_all(reasons)` to see all valid reasons.",
+        x = glue("{value} does not match an existing reason ID.")
+      )
+      abort(bullets, call = error_call)
+    } else if(is.character(value) & !(value %in% show_all_reasons()$name)) {
       bullets <- c(
         "Invalid download reason name.",
         i = "Use `show_all(reasons)` to see all valid reasons.",
@@ -245,8 +253,18 @@ enforce_download_reason <- function(value, error_call = caller_env()){
       )
       abort(bullets, call = error_call)
     }
+    if (is.character(value) & (value %in% show_all_reasons()$name)) {
+      valid_reasons <- show_all_reasons()
+      value_id <- valid_reasons |>
+        filter(valid_reasons$name == value) |>
+        select("id") |>
+        pull("id")
+      inform(c("v" = glue("Matched \"{value}\" to valid download reason ID {value_id}.")))
+      value_id
+    }else{
+      value
+    }
   }
-  value
 }
 
 #' catch all failure for unknown names
@@ -296,7 +314,6 @@ configure_atlas <- function(query){
   }
 }
 
-
 #' Provide a message if atlas is changed
 #' @importFrom glue glue
 #' @importFrom rlang inform
@@ -307,26 +324,5 @@ check_atlas <- function(current_data, new_data){
     inform(glue(
       "Atlas selected: {new_data$organisation} ({new_data$acronym}) [{new_data$region}]"))
   }
-}
-
-
-#' Ensure download reasons are valid
-#' @importFrom rlang abort
-#' @importFrom glue glue
-#' @noRd
-#' @keywords Internal
-convert_reason <- function(value, error_call = caller_env()) {
-  # convert text reason to numeric reason id
-  if (is.character(value) & (value %in% show_all_reasons()$name)) {
-    valid_reasons <- show_all_reasons()
-    value_id <- valid_reasons |>
-      filter(valid_reasons$name == value) |>
-      select("id") |>
-      pull("id")
-    inform(c("v" = glue("Matched \"{value}\" to valid download reason ID {value_id}.")))
-    value <- value_id
-    return(value)
-  }else{
-    value
-  }
-}
+  new_data
+}
\ No newline at end of file
