@@ -1,14 +1,14 @@
 #' Internal function to run metadata checks
 #' This is useful for testing, particularly in testing `galah_select()`
 #' called by `collapse()`
+#' @importFrom utils URLdecode
 #' @noRd
 #' @keywords Internal
 parse_checks <- function(.query){
   # "data/" functions require pre-processing of metadata,
   # as do `unnest()`/`show_values()` functions
   if(grepl("^data/", .query$type) |
-     grepl("-unnest$", .query$type)
-  ){
+     grepl("-unnest$", .query$type)){
     # some checks should happen regardless of `run_checks`
     .query <- .query |>
       check_identifiers() |> 
@@ -20,6 +20,10 @@ parse_checks <- function(.query){
         check_fields() |>
         check_profiles()
     }
+    if(.query$type == "data/distributions" & !is.null(.query[["metadata/distributions"]])){
+      .query$url <- tibble(url = glue(URLdecode(.query$url), 
+                                      id = .query[["metadata/distributions"]]$id))
+    }
     .query <- remove_metadata(.query)
   }
   .query
