@@ -23,7 +23,8 @@ test_that("atlas_occurrences gives a nice error for invalid emails", {
   galah_config(email = "ala4r@ala.org.au")
 })
 
-test_that("collapse(type = 'occurrences') creates an object, but doesn't ping an API", {
+test_that("collapse(type = 'occurrences') creates an object", {
+  skip_if_offline()
   result <- galah_call() |> 
     identify("Perameles") |>
     collapse()
@@ -41,7 +42,7 @@ test_that("`compute(type = 'occurrences')` works", {
   # collapse
   query_collapse <- collapse(base_query)
   expect_true(inherits(query_collapse, "query"))
-  expect_equal(length(query_collapse), 3)
+  expect_equal(length(query_collapse), 4)
   expect_equal(query_collapse$type, "data/occurrences")
   # compute
   response <- compute(base_query)
