@@ -42,17 +42,15 @@ test_that("grouped atlas_counts returns expected output when limit != NULL", {
   expect_equal(nrow(counts), 3)
 })
 
-## FIXME: results of single group_by are not a tibble
 test_that("atlas_counts returns all counts if no limit is provided", {
   skip_if_offline()
   counts <- galah_call() |>
-    group_by(month) |>
-    atlas_counts()
+    group_by(basisOfRecord) |> # NOTE: basisOfRecord chosen as prone to breaking
+    atlas_counts()             # this code; please do not change it!
   expect_s3_class(counts, c("tbl_df", "tbl", "data.frame"))
-  expect_equal(nrow(counts), 12)
+  expect_gte(nrow(counts), 5)
 })
 
-## FIXME: results of single group_by are not a tibble
 test_that("grouped atlas_counts for species returns expected output", {
   skip_if_offline()
   counts <- galah_call() |>
@@ -79,6 +77,21 @@ test_that("group_by works for three groups", {
                     c("basisOfRecord", "year", "stateProvince", "count")))
 })
 
+test_that("group_by returns correct information when ID fields are requested", {
+  # NOTE: previously these were parsed as the `label` for that field, not the 
+  # value itself, hence this test
+  skip_if_offline()
+  counts <- galah_call() |> 
+    identify("pardalotus quadragintus") |> 
+    filter(year == 2023) |>
+    group_by(species, dataResourceName, dataResourceUid) |> 
+    count() |>
+    collect()
+  expect_equal(colnames(counts),
+               c("species", "dataResourceName", "dataResourceUid", "count"))
+  expect_false(any(counts$dataResourceName == counts$dataResourceUid))
+})
+
 test_that("group_by fails for four groups", {
   skip_if_offline()
   galah_call() |>
