@@ -155,17 +155,36 @@ test_that("atlas_species works for France", {
 
 test_that("atlas_occurrences works for France", {
   skip_if_offline()
-  galah_config(email = "ala4r@ala.org.au")
-  x <- galah_call() |>
+  galah_config(atlas = "France",
+               email = "ala4r@ala.org.au")
+  base_query <- galah_call() |>
     filter(year <= 1950) |>
-    identify("Vulpes vulpes") |>
-    select(species, year) |>
-    collect() |>
+    identify("Vulpes vulpes")
+  counts <- base_query |>
+    count() |>
+    collect()
+  occ_collapse <-  base_query |>
+    # select(species, year) |>
+    collapse() |>
     try(silent = TRUE)
-  skip_if(inherits(x, "try-error"), message = "API not available")
-  expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
-  expect_gt(nrow(x), 1)
-  expect_equal(names(x), c("species", "year"))
+  skip_if(inherits(occ_collapse, "try-error"), message = "API not available")
+  expect_s3_class(occ_collapse, "query")
+  expect_equal(names(occ_collapse), 
+               c("type", "url", "headers", "filter"))
+  expect_equal(occ_collapse$type, "data/occurrences")
+  # compute
+  occ_compute <- compute(occ_collapse) |>
+    try(silent = TRUE)
+  skip_if(inherits(occ_compute, "try-error"), message = "API not available")
+  expect_s3_class(occ_compute, "computed_query")
+  # collect
+  occ <- collect(occ_compute) |>
+    try(silent = TRUE)
+  skip_if(inherits(occ, "try-error"), message = "API not available")
+  expect_equal(nrow(occ), counts$count[1])
+  expect_s3_class(occ, c("tbl_df", "tbl", "data.frame"))
+  expect_equal(ncol(occ), 8)
+  unlink("temp", recursive = TRUE)
 })
 
 galah_config(atlas = "Australia")
\ No newline at end of file
