@@ -323,11 +323,11 @@ test_that("atlas_species works for GBIF", {
   expect_gt(nrow(z), 0)
   expect_gt(ncol(z), 0)
   expect_true(inherits(z, c("tbl_df", "tbl", "data.frame")))
-  species <- galah_call() |>
-    galah_filter(year == 2010) |>
-    galah_identify("Litoria") |>
-    atlas_species()
-  expect_equal(z, species)
+  # species <- galah_call() |>
+  #   galah_filter(year == 2010) |>
+  #   galah_identify("Litoria") |>
+  #   atlas_species()
+  # expect_equal(z, species)
 })
 
 test_that("atlas_media fails for GBIF", {
