@@ -176,7 +176,7 @@ test_that("atlas_counts works with group_by for United Kingdom", {
   expect_equal(names(result), c("year", "count"))
 })
 
-test_that("atlas_species fails for UK due to unavailable API", {
+test_that("atlas_species works for United Kingdom, but doesn't return data", {
   skip_if_offline()
   galah_config(
     atlas = "United Kingdom",
@@ -184,9 +184,12 @@ test_that("atlas_species fails for UK due to unavailable API", {
     run_checks = TRUE,
     download_reason_id = 10,
     send_email = FALSE)
-  expect_error({galah_call(type = "species") |>
+  x <- galah_call() |>
       identify("Canidae") |>
-      atlas_species()})
+      atlas_species()
+  expect_s3_class(x, c("tbl_df", "tbl", "data.frame"))
+  expect_equal(nrow(x), 0)
+  expect_equal(ncol(x), 0)
 })
 
 test_that("atlas_occurrences works for United Kingdom", {
@@ -215,7 +218,7 @@ test_that("atlas_occurrences works for United Kingdom", {
   # with run checks, this gives n = 5. Without it's n = 2
   expect_s3_class(occ_collapse, "query")
   expect_equal(names(occ_collapse), 
-               c("type", "url", "headers"))
+               c("type", "url", "headers", "filter"))
   expect_equal(occ_collapse$type, "data/occurrences")
   # compute
   # notes: 
@@ -236,4 +239,30 @@ test_that("atlas_occurrences works for United Kingdom", {
   unlink("temp", recursive = TRUE)
 })
 
+test_that("atlas_media() works for UK", {
+  skip_if_offline()
+  galah_config(
+    atlas = "United Kingdom",
+    email = "ala4r@ala.org.au",
+    run_checks = TRUE,
+    download_reason_id = 10,
+    directory = "temp",
+    send_email = FALSE)
+  x <- request_data() |>
+    filter(year >= 2020) |>
+    atlas_media() |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
+  expect_s3_class(x, c("tbl_df", "tbl", "data.frame"))
+  expect_gte(nrow(x), 1)
+  expect_equal(colnames(x)[1:2],
+               c("media_id", "recordID"))
+  # download a subset
+  n_downloads <- 5
+  collect_media(x[seq_len(n_downloads), ])
+  expect_equal(length(list.files("temp", pattern = ".jpg$")),
+               n_downloads)
+  unlink("temp", recursive = TRUE)
+})
+
 galah_config(atlas = "Australia")
\ No newline at end of file
